==> cloudt-boot-starter-threadpool-3.3.25.2-0614-20240605.064309-1-sources.jar: com/elitescloud/boot/threadpool/support/CustomTaskExecutor.java <==
package com.elitescloud.boot.threadpool.support;

import cn.hutool.core.text.CharSequenceUtil;
import com.dtp.common.config.DtpProperties;
import com.dtp.common.config.ThreadPoolProperties;
import com.dtp.core.DtpRegistry;
import com.dtp.core.thread.DtpExecutor;
import com.elitescloud.boot.threadpool.common.ThreadPoolHolder;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.lang.NonNull;
import org.springframework.scheduling.concurrent.ThreadPoolTaskExecutor;
import org.springframework.util.CollectionUtils;

import java.util.concurrent.ExecutorService;
import java.util.concurrent.RejectedExecutionHandler;
import java.util.concurrent.ThreadFactory;
import java.util.concurrent.ThreadPoolExecutor;

/**
 * 自定义TaskExecutor.
 *
 * @author Kaiser（wang shao）
 * @date 2022/2/20
 */
public class CustomTaskExecutor extends ThreadPoolTaskExecutor {
    private static final Logger LOG = LoggerFactory.getLogger(CustomTaskExecutor.class);
    private static final long serialVersionUID = -669239293574082521L;

    public static final String CLOUDT_DTP_DEFAULT = "cloudT-dtp-default";
    public static final String CLOUDT_TP = "cloudT-tp-";

    private static volatile DtpExecutor dtpExecutor;

    public CustomTaskExecutor(DtpProperties dtpProperties) {
        buildDtpExecutor(dtpProperties);
    }

    @Override
    public void execute(@NonNull Runnable task) {
        if (dtpExecutor == null) {
            dtpExecutor = DtpRegistry.getDtpExecutor(CLOUDT_DTP_DEFAULT);
        }
        dtpExecutor.execute(task);
    }

    @NonNull
    @Override
    protected ExecutorService initializeExecutor(@NonNull ThreadFactory threadFactory, @NonNull RejectedExecutionHandler rejectedExecutionHandler) {
        if (dtpExecutor == null) {
            if (DtpRegistry.listAllDtpNames().contains(CLOUDT_DTP_DEFAULT)) {
                dtpExecutor = DtpRegistry.getDtpExecutor(CLOUDT_DTP_DEFAULT);
            } else {
                dtpExecutor = this.createDefault(8, 17, 256);
            }
        }

        return dtpExecutor;
    }

    @Override
    public ThreadPoolExecutor getThreadPoolExecutor() throws IllegalStateException {
        if (dtpExecutor == null) {
            dtpExecutor = DtpRegistry.getDtpExecutor(CLOUDT_DTP_DEFAULT);
        }
        return dtpExecutor;
    }

    private void buildDtpExecutor(DtpProperties dtpProperties) {
        var executorsConfigs = dtpProperties.getExecutors();
        if (dtpProperties.isEnabled() && !CollectionUtils.isEmpty(executorsConfigs)) {
            for (ThreadPoolProperties executorsConfig : executorsConfigs) {
                if (CharSequenceUtil.equals(executorsConfig.getThreadPoolName(), CLOUDT_DTP_DEFAULT)) {
                    // 已存在相关配置，则DtpRegistry.afterPropertiesSet()会自动创建，无需手动创建
                    LOG.info("ThreadPool Config will use config center");
                    this.createDefault(executorsConfig.getCorePoolSize(), executorsConfig.getMaximumPoolSize(), executorsConfig.getQueueCapacity());
                    return;
                }
            }
        }
    }

    private DtpExecutor createDefault(int coreSize, int maxSize, int queueCapacity) {
        if (dtpExecutor != null) {
            return dtpExecutor;
        }
        LOG.info("ThreadPool Config will create default manually：{}, {}, {}", coreSize, maxSize, queueCapacity);
        dtpExecutor =  (DtpExecutor) ThreadPoolHolder.createThreadPool(CLOUDT_DTP_DEFAULT, CLOUDT_TP, coreSize, maxSize, queueCapacity);
        return dtpExecutor;
    }
}

==> cloudt-boot-starter-threadpool-3.3.83-20250324.143742-1-sources.jar: com/elitescloud/boot/threadpool/support/CustomTaskExecutor.java <==
package com.elitescloud.boot.threadpool.support;

import cn.hutool.core.text.CharSequenceUtil;
import com.elitescloud.boot.threadpool.common.ThreadPoolHolder;
import org.dromara.dynamictp.common.properties.DtpProperties;
import org.dromara.dynamictp.core.DtpRegistry;
import org.dromara.dynamictp.core.executor.DtpExecutor;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.lang.NonNull;
import org.springframework.scheduling.concurrent.ThreadPoolTaskExecutor;
import org.springframework.util.CollectionUtils;

import java.util.concurrent.ExecutorService;
import java.util.concurrent.RejectedExecutionHandler;
import java.util.concurrent.ThreadFactory;
import java.util.concurrent.ThreadPoolExecutor;

/**
 * 自定义TaskExecutor.
 *
 * @author Kaiser（wang shao）
 * @date 2022/2/20
 */
public class CustomTaskExecutor extends ThreadPoolTaskExecutor {
    private static final Logger LOG = LoggerFactory.getLogger(CustomTaskExecutor.class);
    private static final long serialVersionUID = -669239293574082521L;

    public static final String CLOUDT_DTP_DEFAULT = "cloudT-dtp-default";
    public static final String CLOUDT_TP = "cloudT-tp-";

    private static volatile DtpExecutor dtpExecutor;

    public CustomTaskExecutor(DtpProperties dtpProperties) {
        buildDtpExecutor(dtpProperties);
    }

    @Override
    public void execute(@NonNull Runnable task) {
        if (dtpExecutor == null) {
            dtpExecutor = DtpRegistry.getDtpExecutor(CLOUDT_DTP_DEFAULT);
        }
        dtpExecutor.execute(task);
    }

    @NonNull
    @Override
    protected ExecutorService initializeExecutor(@NonNull ThreadFactory threadFactory, @NonNull RejectedExecutionHandler rejectedExecutionHandler) {
        if (dtpExecutor == null) {
            if (DtpRegistry.getAllExecutorNames().contains(CLOUDT_DTP_DEFAULT)) {
                dtpExecutor = DtpRegistry.getDtpExecutor(CLOUDT_DTP_DEFAULT);
            } else {
                dtpExecutor = this.createDefault(8, 17, 256);
            }
        }

        return dtpExecutor;
    }

    @Override
    public ThreadPoolExecutor getThreadPoolExecutor() throws IllegalStateException {
        if (dtpExecutor == null) {
            dtpExecutor = DtpRegistry.getDtpExecutor(CLOUDT_DTP_DEFAULT);
        }
        return dtpExecutor;
    }

    private void buildDtpExecutor(DtpProperties dtpProperties) {
        var executorsConfigs = dtpProperties.getExecutors();
        if (dtpProperties.isEnabled() && !CollectionUtils.isEmpty(executorsConfigs)) {
            for (var executorsConfig : executorsConfigs) {
                if (CharSequenceUtil.equals(executorsConfig.getThreadPoolName(), CLOUDT_DTP_DEFAULT)) {
                    // 已存在相关配置，则DtpRegistry.afterPropertiesSet()会自动创建，无需手动创建
                    LOG.info("ThreadPool Config will use config center");
                    this.createDefault(executorsConfig.getCorePoolSize(), executorsConfig.getMaximumPoolSize(), executorsConfig.getQueueCapacity());
                    return;
                }
            }
        }
    }

    private DtpExecutor createDefault(int coreSize, int maxSize, int queueCapacity) {
        if (dtpExecutor != null) {
            return dtpExecutor;
        }
        LOG.info("ThreadPool Config will create default manually：{}, {}, {}", coreSize, maxSize, queueCapacity);
        dtpExecutor =  (DtpExecutor) ThreadPoolHolder.createThreadPool(CLOUDT_DTP_DEFAULT, CLOUDT_TP, coreSize, maxSize, queueCapacity);
        return dtpExecutor;
    }
}
